<?php $TRANSLATIONS = array(
"Settings" => "Налаштування",
"January" => "Січень",
"February" => "Лютий",
"March" => "Березень",
"April" => "Квітень",
"May" => "Травень",
"June" => "Червень",
"July" => "Липень",
"August" => "Серпень",
"September" => "Вересень",
"October" => "Жовтень",
"November" => "Листопад",
"December" => "Грудень",
"Cancel" => "Відмінити",
"No" => "Ні",
"Yes" => "Так",
"Error" => "Помилка",
"Password" => "Пароль",
"You will receive a link to reset your password via Email." => "Ви отримаєте посилання для скидання вашого паролю на e-mail.",
"Username" => "Ім'я користувача",
"Your password was reset" => "Ваш пароль був скинутий",
"To login page" => "До сторінки входу",
"New password" => "Новий пароль",
"Reset password" => "Скинути пароль",
"Personal" => "Особисте",
"Users" => "Користувачі",
"Admin" => "Адміністратор",
"Help" => "Допомога",
"Add" => "Додати",
"Configure the database" => "Налаштування бази даних",
"will be used" => "буде використано",
"Database user" => "Користувач бази даних",
"Database password" => "Пароль для бази даних",
"Database name" => "Назва бази даних",
"Finish setup" => "Завершити налаштування",
"web services under your control" => "веб-сервіс під вашим контролем",
"Log out" => "Вихід",
"Lost your password?" => "Забули пароль?",
"remember" => "запам'ятати",
"Log in" => "Вхід"
);
